Application payload envelopes stored by KennedyServer in opaque Kweb objects.
Structs
- Error
- A rejected envelope input or invalid stored payload.
- Stored
Artifact - One object referenced by a stored provenance payload.
- Stored
File - A decoded Kweb application file payload.
- Stored
Provenance - KennedyServer provenance stored as one opaque Kweb object payload.
Functions
- decode_
file - Decodes one file payload without reading its Kweb object.
- decode_
provenance - Decodes one provenance payload without reading its Kweb object.
- encode_
file - Encodes one file payload without storing it.
- encode_
provenance - Encodes one provenance payload without storing it.
- sanitize_
file_ name - Returns a bounded safe basename, sanitizing
fallbackby the same policy.
Type Aliases
- Result
- Result type for envelope operations.