pub fn decode_provenance(bytes: &[u8]) -> Result<StoredProvenance>Expand description
Decodes one provenance payload without reading its Kweb object.
pub fn decode_provenance(bytes: &[u8]) -> Result<StoredProvenance>Decodes one provenance payload without reading its Kweb object.